TaskMovedEvent class

Event fired when a task is moved between columns.

Inheritance

Constructors

TaskMovedEvent(Task task, KanbanColumn source, KanbanColumn destination)
Creates a new task moved event.

Properties

destination KanbanColumn
The destination column to which the task was moved.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source KanbanColumn
The source column from which the task was moved.
final
task Task
The task that was moved.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited