TaskReorderedEvent class

Event fired when a task is reordered within a column.

Inheritance

Constructors

TaskReorderedEvent(KanbanColumn column, Task task, int oldIndex, int newIndex)
Creates a new task reordered event.

Properties

column KanbanColumn
The column where the reordering occurred.
final
hashCode int
The hash code for this object.
no setterinherited
newIndex int
The new index of the task.
final
oldIndex int
The original index of the task.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task Task
The task that was reordered.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited