ui/theme/kanban_theme library

Classes

KanbanTheme
A comprehensive theme for the Kanban board.
KanbanThemeProvider
An inherited widget that provides theme access to its descendants.

Extensions

HexColor on String
Extension to convert hex string colors to Flutter Color objects.