TaskAddedEvent class
Event fired when a new task is added to a column.
- Inheritance
-
- Object
- BoardEvent
- TaskAddedEvent
Constructors
- TaskAddedEvent(Task task, KanbanColumn column)
- Creates a new task added event.
Properties
- column → KanbanColumn
-
The column where the task was added.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task → Task
-
The task that was added.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited