TaskEditedEvent class
Event fired when a task is edited.
- Inheritance
-
- Object
- BoardEvent
- TaskEditedEvent
Constructors
- TaskEditedEvent(Task oldTask, Task newTask, KanbanColumn column)
- Creates a new task edited event.
Properties
- column → KanbanColumn
-
The column containing the edited task.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newTask → Task
-
The updated task after editing.
final
- oldTask → Task
-
The original task before editing.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited