TaskRemovedEvent class
Event fired when a task is removed from a column.
- Inheritance
-
- Object
- BoardEvent
- TaskRemovedEvent
Constructors
- TaskRemovedEvent(Task task, KanbanColumn column)
- Creates a new task removed event.
Properties
- column → KanbanColumn
-
The column from which the task was removed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task → Task
-
The task that was removed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited