BoardProvider class
Provider class that manages the state of a Kanban board.
Handles all board-related operations including loading, saving, and updating the board state, as well as managing tasks within columns.
- Inheritance
-
- Object
- ChangeNotifier
- BoardProvider
Constructors
Properties
- board ↔ Board?
-
The current board instance being managed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
addTask(
String columnId, Task task) → void - Adds a new task to the specified column.
-
clearDoneColumn(
String columnId) → Result< List< Task> > - Clears all tasks from the Done column.
-
deleteDoneTask(
String columnId, int index) → Result< Task> - Deletes a task from the Done column.
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
editTask(
String columnId, int index, String newTitle, String newSubtitle) → Result< Task> - Edits an existing task in the specified column.
-
loadBoard(
{Map< String, dynamic> ? config}) → Future<void> - Loads the board from storage or creates a new one.
-
moveTask(
String sourceColId, int sourceIndex, String destColId, [int? destinationIndex]) → void - Moves a task between columns.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeTask(
String columnId, int index) → Result< Task> - Removes a task from the specified column.
-
reorderTask(
String columnId, int oldIndex, int newIndex) → void - Reorders a task within its column.
-
saveBoard(
) → Future< void> - Saves the current board state to storage.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateBoard(
) → Future< void> - Updates the current board state in storage.
-
updateColumnLimit(
String columnId, int? newLimit) → Future< void> - Updates the task limit for a specific column.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited